@@ -12,10 +12,12 @@ from info import bzr_compatible_versions, subvertpy_minimum_version
 def update_relation(l, pkg, kind, version):
     found = False
     for pr in l:
-        for e in pr:
-            if e["name"] == pkg and e["version"] and e["version"][0] == kind:
-                e["version"] = (kind, version)
-                found = True
+        if len(pr) != 1: # only update simple build deps
+            continue
+        e = pr[0]
+        if e["name"] == pkg and e["version"] and e["version"][0] == kind:
+            e["version"] = (kind, version)
+            found = True
     if not found:
         l.append([{"version": (kind, version), "name": pkg, "arch": None}])
 
@@ -25,8 +27,8 @@ source = Deb822(f)
 
 def update_deps(control, field):
     bdi = PkgRelation.parse_relations(control[field])
-    update_relation(bdi, "bzr", ">=", "%d.%d~" % bzr_compatible_versions[0][:2])
-    update_relation(bdi, "bzr", "<<", "%d.%d~" % (bzr_compatible_versions[-1][0], bzr_compatible_versions[-1][1]+1))
+    update_relation(bdi, "python-bzr-lib", ">=", "%d.%d~" % bzr_compatible_versions[0][:2])
+    update_relation(bdi, "python-bzrlib", "<<", "%d.%d.0" % (bzr_compatible_versions[-1][0], bzr_compatible_versions[-1][1]+1))
     update_relation(bdi, "python-subvertpy", ">=", "%d.%d.%d~" % subvertpy_minimum_version)
     control[field] = PkgRelation.str(bdi)
 
